@@ -86,10 +86,26 @@ class PythonVersionTagger(TaggerInterface):
             raise error
 
 
-class PythonProjectTagger(TaggerInterface):
+class PythonProjectVersionTagger(TaggerInterface):
     @staticmethod
     def tag_value(container) -> str:
-        pyproject = DockerRunner.run_simple_command(container, "cat pyproject.toml", False).split("\n")
+        pyproject = DockerRunner.run_simple_command(
+            container,
+            "cat pyproject.toml",
+        ).split("\n")
         for line in pyproject:
             if line.startswith("version"):
                 return line.split("=")[1].strip(' "')
+
+
+class PythonProjectMinorMajorVersionTagger(TaggerInterface):
+    @staticmethod
+    def tag_value(container) -> str:
+        pyproject = DockerRunner.run_simple_command(
+            container,
+            "cat pyproject.toml",
+        ).split("\n")
+        for line in pyproject:
+            if line.startswith("version"):
+                v = line.split("=")[1].strip(' "')
+                return v[:v.rfind(".")]
